Sparse-checkout from NVIDIA/cccl main branch to complete cccl_upstream: Added: - python/cuda_cccl/ (226 files) — Python bindings for device-level algorithms Critical for muh toolchain: cuda.compute.reduce_into, scan, radix_sort, etc. Includes 204 .py files with full test coverage for all 27 algorithms - ci/ (163 files) — Build/test infrastructure build_cub.sh, test_cub.sh, build_and_test_targets.sh, matrix.yaml Directly maps to our [INFRA-CI] and [INFRA-BUILD] items - .agent/skills/ (7 files) — NVIDIA's own agent skills for CCCL cccl-style/SKILL.md, cccl-test/SKILL.md, sass-diff/SKILL.md - docs/ (491 files) — Official CCCL documentation CI references, CMake guides, Python compute docs, libcudacxx PTX docs - test/ (12 files) — Top-level integration tests (cuda_smoke, stdpar) - Root configs: .clang-format, .clang-tidy, CONTRIBUTING.md, pyproject.toml - CLAUDE.md symlink → AGENTS.md (NVIDIA's standard) cccl_upstream now mirrors full NVIDIA/cccl structure: Before: 42M (cub + thrust + libcudacxx + cudax + c + examples + benchmarks) After: 53M (+python +ci +docs +.agent +test +configs) This completes the CCCL base needed for: - [muh-bench] items: ci/util/build_and_test_targets.sh for targeted builds - [CCCL-verify] items: python/cuda_cccl/tests/ as reference implementations - [CCCL-test] items: ci/test_cub.sh, ci/test_thrust.sh - Agent workflow: .agent/skills/ for consistent style and test patterns
195 lines
5.2 KiB
ReStructuredText
195 lines
5.2 KiB
ReStructuredText
..
|
|
This file was automatically generated. Do not edit.
|
|
|
|
fence.sc.cta
|
|
^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 1. PTX ISA 60, SM_70
|
|
// .sem = { .sc }
|
|
// .scope = { .cta, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_sc_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.sc.gpu
|
|
^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 1. PTX ISA 60, SM_70
|
|
// .sem = { .sc }
|
|
// .scope = { .cta, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_sc_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.sc.sys
|
|
^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 1. PTX ISA 60, SM_70
|
|
// .sem = { .sc }
|
|
// .scope = { .cta, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_sc_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.sc.cluster
|
|
^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 2. PTX ISA 78, SM_90
|
|
// .sem = { .sc }
|
|
// .scope = { .cluster }
|
|
template <typename = void>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_sc_t,
|
|
cuda::ptx::scope_cluster_t);
|
|
|
|
fence.acq_rel.cta
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 1. PTX ISA 60, SM_70
|
|
// .sem = { .acq_rel }
|
|
// .scope = { .cta, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acq_rel_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.acq_rel.gpu
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 1. PTX ISA 60, SM_70
|
|
// .sem = { .acq_rel }
|
|
// .scope = { .cta, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acq_rel_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.acq_rel.sys
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 1. PTX ISA 60, SM_70
|
|
// .sem = { .acq_rel }
|
|
// .scope = { .cta, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acq_rel_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.acq_rel.cluster
|
|
^^^^^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // 2. PTX ISA 78, SM_90
|
|
// .sem = { .acq_rel }
|
|
// .scope = { .cluster }
|
|
template <typename = void>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acq_rel_t,
|
|
cuda::ptx::scope_cluster_t);
|
|
|
|
fence.acquire.cta
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .acquire }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acquire_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.acquire.cluster
|
|
^^^^^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .acquire }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acquire_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.acquire.gpu
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .acquire }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acquire_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.acquire.sys
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .acquire }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_acquire_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.release.cta
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .release }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_release_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.release.cluster
|
|
^^^^^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .release }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_release_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.release.gpu
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .release }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_release_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|
|
|
|
fence.release.sys
|
|
^^^^^^^^^^^^^^^^^
|
|
.. code-block:: cuda
|
|
|
|
// fence.sem.scope; // PTX ISA 86, SM_90
|
|
// .sem = { .release }
|
|
// .scope = { .cta, .cluster, .gpu, .sys }
|
|
template <cuda::ptx::dot_scope Scope>
|
|
__device__ static inline void fence(
|
|
cuda::ptx::sem_release_t,
|
|
cuda::ptx::scope_t<Scope> scope);
|